# TypedDict to JsonSchema

Python package that converts valid PEP589 TypedDict Class Definitions into
valid JsonSchema definitions.

## Getting Started

```sh
pip install typeddict2jsonschema
```

```
python -m typeddict2jsonschema ./tests/sample/input.py
```

## How to Contribute

Build jsonschemagenerator.py

```sh
python -m build
```

Create a virtualenv and install the package in the virtualenv

```sh
python -m pip .\dist\typeddict2jsonschema-0.0.1.tar.gz
```
